
# basic models for international comaprative paper
# using rma (metafor) with robust option
# FINAL SOCIOLOGICAL SCIENCE version of analyses and graphs

rm(list=ls())

#install.packages("ggplot2")
library(ggplot2)

#install.packages("gtools")
library(gtools)

#install.packages("metafor")
library(metafor)

#install.packages("robumeta")
library (robumeta)

#install.packages("foreign")
library (foreign)

#install.packages("multcomp")
library (multcomp)

#install.packages("plyr")
library (plyr)

#install.packages("tidyr")
library(tidyr)

#install.packages("gdata")
library (gdata)

#install.packages("readstata13")
library(readstata13)

#install.packages("ggrepel")
library(ggrepel)


tabtocsv <- function(data, file, label) {
  write.table(label, file, sep=",", append=TRUE, row.names=FALSE)
  write.table(data, file, sep=",", append=TRUE, row.names=FALSE)
}

rmatocsv <- function(data, file, label) {
  write.table(label, file, sep=",", append=TRUE, row.names=FALSE)
  write.table(toString(data$call), file, sep=",", append=TRUE, row.names=FALSE)
  q <- cbind(data$b,data$se,data$zval,data$pval,data$ci.lb,data$ci.ub, stars.pval(data$pval))
  colnames(q) <- c("coef", "se", "t", "p-value", "ci.lb", "ci.ub", "sig")
  write.table(q, file, sep=",", append=TRUE, col.names=NA)
  if (is.null(data$n)) { 
    data$n=matrix(NA,1,1)
  }
  z <- cbind(data$k,data$n, data$tau2, data$I2, data$R2, data$parms)
  colnames(z) <- c("Effects","Clusters", "Tau Sq", "I2","R2", "Parms")
  write.table(z, file, sep=",", append=TRUE, row.names=FALSE)
  write.table(data$fit.stats,file, sep=",", append=TRUE, col.names=NA)
}


code2 <- read.dta("dmap_rv7_v4_verysmall.dta")

code2$or_best_lnvar <-code2$or_best_lnse^2

# make country into a factor variable (from a string)
code2$country<-factor(code2$country)

# make min_rec a factor variable
code2$min_rec<-factor(code2$min_rec, labels=c("African/Black", "European/White", "Middle-Eastern/N. African", "Latin Am./Hispanic", "Asian"))

# center to 2000 fieldwork year
code2$cfieldwork_year <- code2$rfieldwork_year-2000

code3 <- subset(code2, complete.cases(code2$min_rec, code2$lrr_best, code2$country))


# below gets rid of factor values that are not present in the code3 data
# namely countries with less than 3 studies we dropped (Australia, etc)
code3$country=factor(code3$country)

# alter country reference level to be us
code3 <- within(code3, country <- relevel(country, ref = "USA"))

# after 1988 study subset
code3n <- subset(code3, rfieldwork_year>1988)

#after 1999 study subset, drop belgium and uk because less than 3 studies
code3r <- subset(code3,rfieldwork_year>1999)
code3r <- subset(code3r, country!="Belgium" & country!="UK")

# below gets list of # of studies by country
ddply(code3,c("country"), summarize, length(unique(studyid)))
ddply(code3n,c("country"), summarize, length(unique(studyid)))

cmc<-ddply(code3,c("country", "min_rec"), nrow)
print(cmc)
ddply(code3n,c("country", "min_rec"), nrow)

# number of studies by country and target group
ddply(code3,c("country","min_rec"), summarize, length(unique(studyid)))
ddply(code3n,c("country","min_rec"), summarize, length(unique(studyid)))


# country differences only
code3t <- subset(code3,min_rec!="European/White")
code3tn <- subset(code3t,rfieldwork_year>1988)

# below gets list of # of studies by country excluding European/white
ddply(code3t,c("country"), summarize, length(unique(studyid)))

# country differences only, non-whites only, averaging over group, descriptive
out2c <- rma(lrr_best, rr_best_lnvar, data=code3t, method="REML", mods=~ country -1, knha=TRUE)
rout2c <- robust(out2c,code3t$studyid2,adjust=TRUE)

# group differences only averaging over country, descriptive
out2g <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ min_rec -1, knha=TRUE)
rout2g <- robust(out2g,code3$studyid2,adjust=TRUE)


## SS article TABLE 1 tabulation of studies and effect sizes

# number of effect sizesand studies by country
t1<-cbind(count(code3,"country"), ddply(code3,c("country"), summarize, length(unique(studyid))))

tabtocsv(t1, "ss2_tab.csv","Effect Sizes and Studies by Country, All Years")

# number of effect sizes and studies by minority group
t4<-cbind(count(code3,"min_rec"), ddply(code3,c("min_rec"), summarize, length(unique(studyid))))

tabtocsv(t4, "ss2_tab.csv","Effect Sizes and Studies by Target Group, All Years")

# below gets list of effect sizes and studies by minority group and country
t7<-cbind(count(code3,c("country","min_rec")),ddply(code3,c("country","min_rec"), summarize, length(unique(studyid))))

tabtocsv(t7, "ss2_tab.csv","Effect Sizes and Studies by Target Group and Country, All Years")

## TABLE 2 COUNTS AND MEANS BELOW
# counts of study method, gender, education
# for now just for all studies
c1<-cbind(count(code3,c("study_method")),ddply(code3,c("study_method"), summarize, length(unique(studyid))))
c2<-cbind(count(code3,c("menonly", "femaleonly")),ddply(code3,c("menonly", "femaleonly"), summarize, length(unique(studyid))))
c3<-cbind(count(code3,c("some_college", "collegeplus", "edmissing")),ddply(code3,c("some_college", "collegeplus", "edmissing"), summarize, length(unique(studyid))))
c4<-cbind(count(code3,c("bluecollar")),ddply(code3,c("bluecollar"), summarize, length(unique(studyid))))
c5<-cbind(count(code3,c("customer_contact")),ddply(code3,c("customer_contact"), summarize, length(unique(studyid))))
c6<-cbind(count(code3,c("office_focus")),ddply(code3,c("office_focus"), summarize, length(unique(studyid))))
c7<-cbind(count(code3,c("foreign_birth")),ddply(code3,c("foreign_birth"), summarize, length(unique(studyid))))
c8<-cbind(count(code3,c("foreign_nationality")),ddply(code3,c("foreign_nationality"), summarize, length(unique(studyid))))
c9<-cbind(count(code3,c("foreign_credentials")),ddply(code3,c("foreign_credentials"), summarize, length(unique(studyid))))

occ<-cbind(c4,c5,c6)
foreign<-cbind(c7,c8,c9)

tabtocsv(c1, "ss2_tab.csv","Study Method")
tabtocsv(c2, "ss2_tab.csv","Gender of Applicants")
tabtocsv(c3, "ss2_tab.csv","Educational Level of Applicants")
tabtocsv(occ, "ss2_tab.csv","Occupational Variables")
tabtocsv(foreign, "ss2_tab.csv","Foreign Characteristics")

m1<-cbind(mean(code3$rfieldwork_year, na.rm=TRUE), mean(code3$ue_bestw, na.rm=TRUE), mean(code3$p_immig, na.rm=TRUE))
s1<-cbind(sd(code3$rfieldwork_year, na.rm=TRUE), sd(code3$ue_bestw, na.rm=TRUE), sd(code3$p_immig, na.rm=TRUE))
v1<-cbind(length(na.omit(code3$rfieldwork_year)), length(na.omit(code3$ue_bestw)) , length(na.omit(code3$p_immig)))

mt1<-rbind(m1,s1,v1)
colnames(mt1)<-c("Fieldwork Year", "Unemployment Tate", "Percentage Immigrants")
rownames(mt1)<-c("mean", "sd", "valid n")

tabtocsv(mt1, "ss2_tab.csv","Means of Continuous Variables")


## counts of applications total and by country

# below gets list of number of applications by minority group and country
ap1<-ddply(code3,c("country","min_rec"), summarize, tot=sum(rr_best_n))

# list of number of applications by country
ap2<-ddply(code3,c("country"), summarize, tot=sum(rr_best_n))

# list of number of applications by min_rec
ap3<-ddply(code3,c("min_rec"), summarize, tot=sum(rr_best_n))


tabtocsv(ap1, "ss2_tab.csv","Effect Sizes and Studies by Target Group and Country, All Years")
tabtocsv(ap2, "ss2_tab.csv","Effect Sizes and Studies by Country, All Years")
tabtocsv(ap3, "ss2_tab.csv","Effect Sizes and Studies by Target Group, All Years")

## FOR TABLE 1:  counts of application by minority group and country eliminating duplicate majority counting
## for common control group

# below gets list of number of applications by minority group and country
nd1<-ddply(code3,c("country","min_rec"), summarize, tot=sum(rr_best_n_nodup))

# list of number of applications by country
nd2<-ddply(code3,c("country"), summarize, tot=sum(rr_best_n_nodup))

# list of number of applications by min_rec
nd3<-ddply(code3,c("min_rec"), summarize, tot=sum(rr_best_n_nodup))


tabtocsv(nd1, "ss2_tab.csv","Effect Sizes and Studies by Target Group and Country, All Years, No Duplicate Majority Cases")
tabtocsv(nd2, "ss2_tab.csv","Effect Sizes and Studies by Country, All Years, No Duplicate Majority Cases")
tabtocsv(nd3, "ss2_tab.csv","Effect Sizes and Studies by Target Group, All Years, No Duplicate Majority Cases")


## TABLE 3 STATISTICS BEGINS HERE
# model w/o controls of country and group effect together (table 3, model 1)

out3 <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ country + min_rec, knha=TRUE)

r3 <- robust(out3,code3$studyid2,adjust=TRUE)

rmatocsv(r3,"ss2.csv","Table 3 Model 1, r3 no controls, table 3 model 1")


# controls for occupation, BASE MODEL (table 3, model 2)

out3c31 <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ country + min_rec + study_method + menonly + femaleonly + cfieldwork_year+some_college+collegeplus+edmissing+bluecollar+customer_contact+office_focus, knha=TRUE)

out3nc31 <- rma(lrr_best, rr_best_lnvar, data=code3n, method="REML", mods=~ country + min_rec + study_method + menonly + femaleonly + cfieldwork_year+some_college+collegeplus+edmissing+bluecollar+customer_contact+office_focus, knha=TRUE)

out3rc31 <- rma(lrr_best, rr_best_lnvar, data=code3r, method="REML", mods=~ country + min_rec + study_method + menonly + femaleonly + cfieldwork_year+some_college+collegeplus+edmissing+bluecollar+customer_contact+office_focus, knha=TRUE)

r3c31 <- robust(out3c31,code3$studyid2,adjust=TRUE)

r3nc31 <- robust(out3nc31,code3n$studyid2,adjust=TRUE)

r3rc31<- robust(out3rc31,code3r$studyid2,adjust=TRUE)

rmatocsv(r3c31,"ss2.csv","r3c31 Full Sample, base model, table 3 model 2")

rmatocsv(r3nc31,"ss2.csv","Full Sample, job characteristics, Since 1989, Appendix Table S1")


# controls for foreign characteristics (table 3, model 3)

out3c3 <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ country + min_rec + study_method + menonly + femaleonly + cfieldwork_year+some_college+collegeplus+edmissing+bluecollar+customer_contact+office_focus+foreign_birth+foreign_nationality+foreign_credentials, knha=TRUE)

r3c3 <- robust(out3c3,code3$studyid2,adjust=TRUE)

rmatocsv(r3c3,"ss2.csv","Table 3 Model 3, r3c3 Full Sample, foreign characteristics")


# controls for base + ue + % immigrants (table 3, model 4)

out3c5 <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ country + min_rec + study_method + menonly + femaleonly + cfieldwork_year+some_college+collegeplus+edmissing+bluecollar+customer_contact+office_focus+ue_bestw+p_immig, knha=TRUE)

r3c5 <- robust(out3c5,code3$studyid2,adjust=TRUE)

rmatocsv(r3c5,"ss2.csv","Table 3 Model 4, r3c5 Full Sample, adds % immigrants")



# FIGURES final sociological science country comparison paper below

# now graph country coefs and cis exponentiated
# for figure 2 as of 5/7/2018
coef1<-cbind(exp(r3c31$b),exp(r3c31$ci.lb), exp(r3c31$ci.ub))
colnames(coef1)<-NULL
cnames<-c("U.S.", "Belgium", "Canada", "France", "Germany", "Great Britain","Netherlands", "Norway", "Sweden")
coef2<-data.frame(rbind(matrix(1,1,3),coef1[2:9,]), cnames)
coef2[,5] <- round(coef2[,1], digits=2)


#ggplot(coef2, aes(x=coef2[,4], y=coef2[,1])) + 
#  geom_pointrange(aes(ymin=coef2[,2], ymax=coef2[,3]), size=1) + 
#  scale_x_discrete(limits=c("U.S.", "Sweden", "Norway", "Netherlands", "Great Britain", "Germany", "France", "Canada", "Belgium")) +
#  theme_bw() + theme(axis.text.x  = element_text(size=12), axis.text.y  = element_text(size=12), panel.grid.major.y = element_blank()) + 
#  labs(y="Ratio of Country Discrimination Ratio to U.S. Discrimination Ratio", x="Country", title="Country Discrimination Effects Relative to the U.S") +
#  theme(text = element_text(size=12), plot.title = element_text(size = 14, face = "bold")) +
#  scale_y_continuous(limits=c(.7, 1.80), breaks=c(.75,1,1.25,1.5,1.75), minor_breaks=NULL) + coord_flip()

# same as above but color
#ggplot(coef2, aes(x=coef2[,4], y=coef2[,1], color=cnames)) + 
#  geom_pointrange(aes(ymin=coef2[,2], ymax=coef2[,3]), size=1) + 
#  scale_x_discrete(limits=c("Sweden", "Norway", "Netherlands", "Great Britain", "Germany", "France", "Canada", "Belgium", "U.S.")) +
#  theme_bw()+theme(axis.text.x  = element_text(size=12), axis.text.y  = element_text(size=12), panel.grid.major.y=element_blank()) + 
#  labs(y="Ratio of Country Discrimination Ratio to U.S. Discrimination Ratio", x="Country", title="Figure 2:Country Discrimination Effects Relative to the U.S") +
#  theme(text = element_text(size=12), plot.title = element_text(size = 14, face = "bold")) +
#  scale_y_continuous(limits=c(.7, 1.80), breaks=c(.75,1,1.25,1.5,1.75), minor_break=NULL) + coord_flip() +
#  theme(legend.position="none") + scale_color_manual(values=c("gray", "red", "blue", "darkgreen", "orange", "skyblue", "salmon", "purple", "black"))


# same as above but color and vertical for final soc sci version

coef2[,5] <- round(coef2[,1], digits=2)

ggplot(coef2, aes(x=coef2[,4], y=coef2[,1], color=cnames)) + 
  geom_pointrange(aes(ymin=coef2[,2], ymax=coef2[,3]), size=1) + 
  scale_x_discrete(limits=c("U.S.", "Belgium", "Canada", "France", "Germany", "Great Britain", "Netherlands", "Norway", "Sweden")) +
  theme_bw() + theme(axis.text.x  = element_text(size=12, angle=65, vjust=0.5), axis.text.y  = element_text(size=12), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) + 
  labs(y="Country Discrimination Coefs (Ratio to U.S.)", x="Country", title="Figure 2: Country Discrimination Levels Relative to U.S.", caption="Note:  Lines are 95% Confidence Intervals.  Based on exponentiated coefficients from table 3 model 2.") +
  theme(text = element_text(size=15), plot.title = element_text(size = 14, face = "bold")) +
  scale_y_continuous(limits=c(.7, 1.80), breaks=c(.75,1,1.25,1.5,1.75), minor_breaks=NULL) +theme(legend.position="none") +
  scale_color_manual(values=c("gray", "red", "blue", "darkgreen", "orange", "skyblue", "salmon", "purple", "black")) + geom_text(aes(label = sprintf("%0.2f", coef2[,5]), hjust=1.50))

# same as above but with no captions because soc sci wants to add in typesetting 
ggplot(coef2, aes(x=coef2[,4], y=coef2[,1], color=cnames)) + 
  geom_pointrange(aes(ymin=coef2[,2], ymax=coef2[,3]), size=1) + 
  scale_x_discrete(limits=c("U.S.", "Belgium", "Canada", "France", "Germany", "Great Britain", "Netherlands", "Norway", "Sweden")) +
  theme_bw() + theme(axis.text.x  = element_text(size=12, angle=65, vjust=0.5), axis.text.y  = element_text(size=12), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) + 
  labs(y="Country Discrimination Coefs (Ratio to U.S.)", x="Country", title="Figure 2: Country Discrimination Levels Relative to U.S.") +
  theme(text = element_text(size=15), plot.title = element_text(size = 14, face = "bold")) +
  scale_y_continuous(limits=c(.7, 1.80), breaks=c(.75,1,1.25,1.5,1.75), minor_breaks=NULL) +theme(legend.position="none") +
  scale_color_manual(values=c("grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple", "black")) + geom_text(aes(label = sprintf("%0.2f", coef2[,5]), hjust=1.50))




#scale_color_manual(values=c("red", "blue", "green", "yellow", "orange", "gray", "pink", "purple", "black"))

# Group Coefs graphed, base model:  code below gives exponentiated coefs and cis
# appear in figure 3 as of 5/7/2018
coef3<-cbind(exp(r3c31$b),exp(r3c31$ci.lb), exp(r3c31$ci.ub))
colnames(coef3)<-NULL
gnames<-c("African/Black","European/White","Middle-Eastern/N. African", "Latin Am/Hispanic","Asian")
coef4<-data.frame(rbind(matrix(1,1,3),coef3[10:13,]), gnames)

coef4[,5] <- round(coef4[,1], digits=2)
# revalue below is from plyr package
coef4$gnames<-revalue(coef4$gnames, c("Middle-Eastern/N. African"="MENA"))


#ggplot(coef4, aes(x=coef4[,4], y=coef4[,1])) + 
#  geom_pointrange(aes(ymin=coef4[,2], ymax=coef4[,3]), size=1) + 
#  scale_x_discrete(limits=c("Asian", "Latin Am/Hispanic", "Middle-Eastern/N. African", "European/White", "African/Black")) +
#  theme_bw() + theme(axis.text.x  = element_text(size=12), axis.text.y  = element_text(size=12), panel.grid.major.y = element_blank()) + 
#  labs(y="Ratio of Minority Group Discrimination Ratio to African/Black Discrimination Ratio", x="Minority Group", title="Minority Group Discrimination Effects Relative to African/Black") +
#  theme(text = element_text(size=12), plot.title = element_text(size = 14, face = "bold")) +
#  scale_y_continuous(limits=c(.7, 1.25), breaks=c(.75,1,1.25), minor_breaks=NULL) + coord_flip()

#groups coefs graphed with color 
#ggplot(coef4, aes(x=coef4[,4], y=coef4[,1], color=gnames)) + 
#  geom_pointrange(aes(ymin=coef4[,2], ymax=coef4[,3]), size=1) + 
#  scale_x_discrete(limits=c("Asian", "Latin Am/Hispanic", "Middle-Eastern/N. African", "European/White", "African/Black")) +
#  theme_bw() + theme(axis.text.x  = element_text(size=12), axis.text.y  = element_text(size=12), panel.grid.major.y = element_blank()) + 
#  labs(y="Ratio of Minority Group Discrimination Ratio to African/Black Discrimination Ratio", x="Minority Group", title="Minority Group Discrimination Effects Relative to African/Black") +
#  theme(text = element_text(size=12), plot.title = element_text(size = 14, face = "bold")) +
#  scale_y_continuous(limits=c(.7, 1.25), breaks=c(.75,1,1.25), minor_breaks=NULL) + coord_flip() + theme(legend.position="none")

# same as above but color and vertical for sociological science
ggplot(coef4, aes(x=coef4[,4], y=coef4[,1], color=gnames)) + 
  geom_pointrange(aes(ymin=coef4[,2], ymax=coef4[,3]), size=1) + 
  scale_x_discrete(limits=c("African/Black", "European/White", "MENA", "Latin Am/Hispanic", "Asian")) +
  theme_bw() + theme(axis.text.x  = element_text(size=12, angle=65, vjust=0.5), axis.text.y  = element_text(size=12), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) + 
  labs(y="Minority Group Coefs (Ratio to African/Black)", x="Minority Group", title="Figure 3: Minority Group Discrimination Levels Relative to African/Black", caption="Note:  Lines are 95% Confidence Intervals.  Based on exponentiated coefficients from table 3 model 2.") +
  theme(text = element_text(size=12), plot.title = element_text(size = 12, face = "bold")) +
  scale_y_continuous(limits=c(.7, 1.25), breaks=c(.75,1,1.25), minor_breaks=NULL)+theme(legend.position="none") +
  scale_color_manual(values=c("black", "purple", "blue", "red", "darkgreen")) + geom_text(aes(label = sprintf("%0.2f", coef4[,5]), hjust=1.50))

# same as above but no caption for sociological science final version
ggplot(coef4, aes(x=coef4[,4], y=coef4[,1], color=gnames)) + 
  geom_pointrange(aes(ymin=coef4[,2], ymax=coef4[,3]), size=1) + 
  scale_x_discrete(limits=c("African/Black", "European/White", "MENA", "Latin Am/Hispanic", "Asian")) +
  theme_bw() + theme(axis.text.x  = element_text(size=12, angle=65, vjust=0.5), axis.text.y  = element_text(size=12), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) + 
  labs(y="Minority Group Coefs (Ratio to African/Black)", x="Minority Group", title="Figure 3: Minority Group Discrimination Levels Relative to African/Black") +
  theme(text = element_text(size=12), plot.title = element_text(size = 12, face = "bold")) +
  scale_y_continuous(limits=c(.7, 1.25), breaks=c(.75,1,1.25), minor_breaks=NULL)+theme(legend.position="none") +
  scale_color_manual(values=c("black", "purple", "blue", "red", "darkgreen")) + geom_text(aes(label = sprintf("%0.2f", coef4[,5]), hjust=1.50))

  
#######################
# model with just country*min_rec as predictor
# with standard error bars and arrows
# FOR GRAPHS
# country by target group model, no other controls
# for a base comparison table or figure
# figure 1 in version of paper 5/7/2018
out3c1d <- rma(lrr_best, rr_best_lnvar, data=code3, method="REML", mods=~ country*min_rec, knha=TRUE)

##IMPORTANT: further analysis found SEs in robust estimates below to be seriously incorrect
r3c1d <- robust(out3c1d,code3$studyid2,adjust=TRUE)

# predictions from model with basic controls, second line some not-present interactions
cmc<-count(code3,c("country","min_rec"))
hold9<-model.matrix( ~ country*min_rec, cmc)

hold10<-hold9[,apply(hold9,2,sum)>0]
# below puts matrices together
#  first dummies for country and target group
# then two columns of zeros for study method and rfieldwork_year
# then interactions of country and target group
# skip interaction terms for Sweden, Germany, Norway, which drop because only 1 target group in country
cpd1<-cbind(hold10[,2:20], hold10[,22], hold10[,24:27], hold10[28])
#cg1<-model.matrix(~counbygroup$country + counbygroup$min_rec)

# using the "rma" output rather than "robust" because robust output here is wrong
#cpd2<-predict(r3c1d,cpd1,addx=TRUE, transf=exp)
cpd2<-predict(out3c1d,cpd1,addx=TRUE, transf=exp)

study_n<-ddply(code3,.(country,min_rec), summarize, length(unique(studyid)))

colnames(study_n)<-c("country", "min_rec","study_n")

cpd3<-data.frame(cbind(cpd2,cmc,study_n$study_n))

# below adds number of gropus in the country to the file
#cmc$grp.num <- ddply(cmc, "country", transform, grp.num = n_distinct(min_rec))

# adds column for ci bars outside range of plot, range here .5 to 3.3, sets line max at 3.3
library(dplyr)
cpd3_m <- cpd3 %>% mutate(ci.lb_f = ifelse(ci.lb < .5, pred - .5, NA), ci.ub_f = ifelse(ci.ub > 3.0, 3.0 - pred, NA), ci.ub = pmin(ci.ub, 3.0))


#ggplot(cpd3_m, aes(x=min_rec, y=pred)) + 
#  geom_pointrange(aes(ymin=ci.lb, ymax=ci.ub), size=1) + 
#  scale_x_discrete(limits = rev(levels(cpd3$min_rec))) +
#  theme_bw() + theme(axis.text.x  = element_text(size=8), panel.grid.major.y = element_blank())  + 
#  labs(y="Discrimination Ratio", x="Country by Group", 
#       title="Average Discrimination Ratios by Country and Target Group", 
#       subtitle="(From Random Effects Meta-Analysis)", 
#       caption="Note:  Lines are 95% Confidence Intervals.  Number to left of line is number of studies used to compute effect.")+
#  geom_text(
#    data    = cpd3_m,
#    mapping = aes(x = min_rec, y = .5, label = cpd3_m$study_n.study_n), size=3)  +
#  coord_cartesian() + facet_wrap(~country, nrow=3) + 
#  scale_y_continuous(limits = c(.5, 3.0), breaks=c(1,1.5,2,2.5), minor_breaks=NULL)+ 
#  geom_segment(aes(x = min_rec, xend = min_rec, y = pred, yend = pred + ci.ub_f), arrow = arrow(length = unit(0.2, "cm")), size=1) +
#  coord_flip()

## same as prior model (country*min_rec) but with color 
#ggplot(cpd3_m, aes(x=min_rec, y=pred, color=country)) + 
#  geom_pointrange(aes(ymin=ci.lb, ymax=ci.ub), size=1) + 
#  scale_x_discrete(limits = rev(levels(cpd3$min_rec))) +
#  theme_bw() + theme(axis.text.x  = element_text(size=8), panel.grid.major.y = element_blank())  + 
#  labs(y="Discrimination Ratio", x="Country by Group", 
#       title="Average Discrimination Ratios by Country and Target Group", 
#       subtitle="(From Random Effects Meta-Analysis)", 
#       caption="Note:  Lines are 95% Confidence Intervals.  Number to left of line is number of studies used to compute effect.")+
#  geom_text(
#    data    = cpd3_m,
#    mapping = aes(x = min_rec, y = .5, label = cpd3_m$study_n.study_n), size=3)  +
#  coord_cartesian() + facet_wrap(~country, nrow=3) + 
#  scale_y_continuous(limits = c(.5, 3.0), breaks=c(1,1.5,2,2.5), minor_breaks=NULL)+ 
#  geom_segment(aes(x = min_rec, xend = min_rec, y = pred, yend = pred + ci.ub_f), arrow = arrow(length = unit(0.2, "cm")), size=1) +
#  coord_flip() +theme(legend.position="none") + scale_color_manual(values=c("black", "gray", "red", "blue", "green", "orange", "skyblue", "salmon", "purple"))

# COLOR, with VERTICAL ORIENTATION OF CIs
## for sociological science
cpd3_m <- cpd3 %>% mutate(ci.lb_f = ifelse(ci.lb < .5, pred - .5, NA), ci.ub_f = ifelse(ci.ub > 3.1, 3.1 - pred, NA), ci.ub = pmin(ci.ub, 3.1))

# below new data with shorter labels for groups to fit on graph
cpd3_c<-cpd3_m
# revalue below is from plyr package
cpd3_c$min_rec<-revalue(cpd3_c$min_rec, c("Asian"="Asian","Latin Am./Hispanic"="Hispanic", "Middle-Eastern/N. African"="MENA", "European/White"="White", "African/Black"="Black"))

ggplot(cpd3_c, aes(x=min_rec, y=pred, color=country)) + 
  geom_pointrange(aes(ymin=ci.lb, ymax=ci.ub), size=1) + 
  scale_x_discrete(limits=levels(cpd3_c$min_rec)) +
  theme_bw() + theme(axis.text.x  = element_text(size=8, angle=65, vjust=0.5), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) +
  labs(y="Discrimination Ratio", x="Minority Group",
       title="Figure 1: Average Discrimination Ratios by Country and Target Group", 
       caption="Note:  Lines are 95% Confidence Intervals.  Number to left of line is point estimate.  Number below the line is number of studies used to compute effect.") +
    geom_text(data    = cpd3_c,mapping = aes(x = min_rec, y = .5, label = cpd3_c$study_n.study_n), size=3)  +
  coord_cartesian() + facet_wrap(~country, nrow=3) + 
  scale_y_continuous(limits = c(.4, 3.1), breaks=c(1,1.5,2,2.5, 3.0), minor_breaks=NULL)+ 
  geom_segment(aes(x = min_rec, xend = min_rec, y = pred, yend = pred + ci.ub_f), arrow = arrow(length = unit(0.2, "cm")), size=1) +
  geom_text(aes(label = sprintf("%0.2f", pred), hjust=1.50), size=3) +
  theme(legend.position="none") + scale_color_manual(values=c("black", "grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple"))

# same as above but dropping caption because soc sci doesn't want caption
ggplot(cpd3_c, aes(x=min_rec, y=pred, color=country)) + 
  geom_pointrange(aes(ymin=ci.lb, ymax=ci.ub), size=1) + 
  scale_x_discrete(limits=levels(cpd3_c$min_rec)) +
  theme_bw() + theme(axis.text.x  = element_text(size=8, angle=65, vjust=0.5), panel.grid.major.x = element_blank(), plot.caption = element_text(hjust = 0)) +
  labs(y="Discrimination Ratio", x="Minority Group",
       title="Figure 1: Average Discrimination Ratios by Country and Target Group") +
  geom_text(data    = cpd3_c,mapping = aes(x = min_rec, y = .5, label = cpd3_c$study_n.study_n), size=3)  +
  coord_cartesian() + facet_wrap(~country, nrow=3) + 
  scale_y_continuous(limits = c(.4, 3.1), breaks=c(1,1.5,2,2.5, 3.0), minor_breaks=NULL)+ 
  geom_segment(aes(x = min_rec, xend = min_rec, y = pred, yend = pred + ci.ub_f), arrow = arrow(length = unit(0.2, "cm")), size=1) +
  geom_text(aes(label = sprintf("%0.2f", pred), hjust=1.50), size=3) +
  theme(legend.position="none") + scale_color_manual(values=c("black", "grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple"))


## NOW MAKE FIGURE 4 ethnic penalties vs. discrimination ratios
ep <- read.dta13("ethnic_penalties_by_group_2.dta")

# create multiple linear model
lm_fit <- lm(ethnicpenalty~disc_ratio, data=ep, weight=1/var1)
summary(lm_fit)

#var1 below is estimate of variance from heath and cheung cis

ggplot(ep, aes(x=disc_ratio, y=ethnicpenalty, color=country)) + 
  theme_bw() +
  scale_y_continuous(limits = c(-.25, 1.75), breaks=c(0,.5,1,1.5), minor_breaks=NULL)+
  scale_x_continuous(limits = c(1.0, 2.1), breaks=c(1,1.5,2), minor_breaks=NULL)+
  geom_point(shape=19, aes(size=1/var1)) + theme(legend.position="none") + geom_text(aes(label=country_grp_full),hjust=0, vjust=1) +
  labs(y="Ethnic Penalty from Heath and Cheung", x="Discrimination Ratio from Meta-Analysis",
       title="Figure 4: Ethnic Penalty and Discrimination by Country and Target Group", 
       caption="Notes: Size of symbol proportional to meta-analysis weight. \nCountry and minority group indicated. MENA is Middle-East/N. African.") +
  geom_segment(aes(x = 1.15, xend = 2.10, y = lm_fit$coefficients[1] + lm_fit$coefficients[2]*1.1, yend = lm_fit$coefficients[1] + lm_fit$coefficients[2]*2.1), color="black") +
    scale_color_manual(values=c("grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple", "black"))

## same as above but no caption for sociological science
ggplot(ep, aes(x=disc_ratio, y=ethnicpenalty, color=country)) + 
  theme_bw() +
  scale_y_continuous(limits = c(-.25, 1.75), breaks=c(0,.5,1,1.5), minor_breaks=NULL)+
  scale_x_continuous(limits = c(1.0, 2.1), breaks=c(1,1.5,2), minor_breaks=NULL)+
  geom_point(shape=19, aes(size=1/var1)) + theme(legend.position="none") + geom_text(aes(label=country_grp_full),hjust=-.1, vjust=1) +
  labs(y="Ethnic Penalty from Heath and Cheung", x="Discrimination Ratio from Meta-Analysis",
       title="Figure 4: Ethnic Penalty and Discrimination by Country and Target Group") +
  geom_segment(aes(x = 1.15, xend = 2.10, y = lm_fit$coefficients[1] + lm_fit$coefficients[2]*1.1, yend = lm_fit$coefficients[1] + lm_fit$coefficients[2]*2.1), color="black") +
  scale_color_manual(values=c("grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple", "black"))

# Figure 4 Sociological Science final version used in manuscript
# Uses ggrepel to elimiante overlap in labels
ggplot(ep, aes(x=disc_ratio, y=ethnicpenalty, color=country)) + 
  theme_bw() +
  scale_y_continuous(limits = c(-.25, 1.75), breaks=c(0,.5,1,1.5), minor_breaks=NULL)+
  scale_x_continuous(limits = c(1.0, 2.1), breaks=c(1,1.5,2), minor_breaks=NULL)+
  geom_point(shape=19, aes(size=1/var1)) + theme(legend.position="none")  +
  labs(y="Ethnic Penalty from Heath and Cheung", x="Discrimination Ratio from Meta-Analysis",
       title="Figure 4: Ethnic Penalty and Discrimination by Country and Target Group") +
  geom_segment(aes(x = 1.15, xend = 2.10, y = lm_fit$coefficients[1] + lm_fit$coefficients[2]*1.1, yend = lm_fit$coefficients[1] + lm_fit$coefficients[2]*2.1), color="black") +
  scale_color_manual(values=c("grey50", "red", "blue", "darkgreen", "olivedrab", "steelblue", "salmon", "purple", "black")) +
  geom_text_repel(aes(label=country_grp_full), point.padding=.2, hjust=.3, segment.color=NA)
